####
then
####


.. image:: https://img.shields.io/travis/Nekmo/then.svg?style=flat-square&maxAge=2592000
  :target: https://travis-ci.org/Nekmo/then
  :alt: Latest Travis CI build status

.. image:: https://img.shields.io/pypi/v/then.svg?style=flat-square
  :target: https://pypi.org/project/then/
  :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/pyversions/then.svg?style=flat-square
  :target: https://pypi.org/project/then/
  :alt: Python versions

.. image:: https://img.shields.io/codeclimate/github/Nekmo/then.svg?style=flat-square
  :target: https://codeclimate.com/github/Nekmo/then
  :alt: Code Climate

.. image:: https://img.shields.io/codecov/c/github/Nekmo/then/master.svg?style=flat-square
  :target: https://codecov.io/github/Nekmo/then
  :alt: Test coverage

.. image:: https://img.shields.io/requires/github/Nekmo/then.svg?style=flat-square
     :target: https://requires.io/github/Nekmo/then/requirements/?branch=master
     :alt: Requirements Status


When "something" THEN send email/sms/telegram/event/execute... or Whatever 


To install then, run this command in your terminal:

.. code-block:: console

    $ sudo pip install then

This is the preferred method to install then, as it will always install the most recent stable release.


Features
========

* TODO

